import { ApiGatewayManagementApiClient, DeleteConnectionCommand, PostToConnectionCommand, } from '@aws-sdk/client-apigatewaymanagementapi';
export class WsApi {
    requestHandlers = {};
    addRouteHandler(route, requestHandler) {
        this.requestHandlers[route.routeKey] = requestHandler;
        return this;
    }
    handleRequest(event) {
        const { body } = event;
        const { connectionId, domainName, stage, routeKey } = event.requestContext;
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        if (!routeKey)
            throw 'No routeKey';
        if (!body)
            throw 'No body';
        const requestHandler = this.requestHandlers[routeKey];
        if (!requestHandler)
            throw `No requestHandler found for routeKey ${routeKey}`;
        const endpoint = `https://${domainName}/${stage}`;
        const ws = new ApiGatewayManagementApiClient({ endpoint });
        requestHandler(JSON.parse(body), {
            sendMessage: async (message) => {
                await ws.send(new PostToConnectionCommand({
                    ConnectionId: connectionId,
                    Data: JSON.stringify(message),
                }));
            },
            closeConnection: async () => {
                await ws.send(new DeleteConnectionCommand({ ConnectionId: connectionId }));
            },
        });
    }
}
//# sourceMappingURL=WsApi.js.map